"use strict";

import { createHighlighterCore } from '@shikijs/core';
import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript';
import React, { useMemo } from 'react';
import { ActivityIndicator, ScrollView, StyleSheet, Text, View } from 'react-native';
import { getStylesFromShikiTheme } from '../../utils/style';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
let highlighterInstance = null;
async function getHighlighter() {
  if (!highlighterInstance) {
    highlighterInstance = await createHighlighterCore({
      engine: createJavaScriptRegexEngine()
    });
  }
  return highlighterInstance;
}
export const SyntaxHighlighter = ({
  text,
  language,
  theme,
  fontSize = 14,
  textStyle,
  scrollViewProps,
  containerStyle
}) => {
  const [tokens, setTokens] = React.useState([]);
  const [loading, setLoading] = React.useState(true);
  const [error, setError] = React.useState(null);

  // Debug theme structure
  React.useEffect(() => {
    console.log('Theme input:', {
      name: theme.name,
      settings: theme.settings?.length,
      colors: theme.colors,
      fg: theme.fg,
      bg: theme.bg
    });
  }, [theme]);

  // Convert theme to RN styles
  const stylesheet = useMemo(() => {
    const styles = getStylesFromShikiTheme(theme);
    console.log('Generated stylesheet:', styles);
    return styles;
  }, [theme]);
  React.useEffect(() => {
    const highlight = async () => {
      try {
        setLoading(true);
        const highlighter = await getHighlighter();

        // Load language and theme
        if (typeof language !== 'string') {
          await highlighter.loadLanguage(language);
        }
        await highlighter.loadTheme(theme);

        // Get the theme name from the registration
        const themeName = theme.name || Object.getOwnPropertyDescriptor(theme, 'name')?.value || 'default';
        console.log('Using theme name:', themeName);

        // Highlight the code
        const result = highlighter.codeToTokens(text, {
          lang: typeof language === 'string' ? language : language.name,
          theme: themeName,
          includeExplanation: true // Enable this to get scope information
        });
        console.log('Tokenization result:', {
          lineCount: result.tokens.length,
          firstLineTokens: result.tokens[0]?.map(t => ({
            content: t.content,
            color: t.color,
            scopes: t.explanation?.[0]?.scopes.map(s => s.scopeName)
          }))
        });
        setTokens(result.tokens);
        setError(null);
      } catch (err) {
        setError(err instanceof Error ? err.message : 'Failed to highlight code');
        console.error('Highlighting error:', err);
      } finally {
        setLoading(false);
      }
    };
    highlight();
  }, [text, language, theme]);
  const renderToken = (token, index) => {
    // Get token scope styles
    const scopeStyles = token.explanation?.[0]?.scopes.map(scope => {
      const style = stylesheet[scope.scopeName];
      if (style) {
        console.log('Found style for scope:', scope.scopeName, style);
      }
      return style;
    }).filter(Boolean) || [];
    const style = StyleSheet.flatten([textStyle, {
      fontSize
    }, ...scopeStyles, token.color ? {
      color: token.color
    } : null, token.fontStyle === 1 && {
      fontStyle: 'italic'
    }, token.fontStyle === 2 && {
      fontWeight: 'bold'
    }, token.fontStyle === 4 && {
      textDecorationLine: 'underline'
    }]);
    console.log('Final token style:', {
      content: token.content,
      color: token.color,
      scopeStyles,
      finalStyle: style
    });
    return /*#__PURE__*/_jsx(Text, {
      style: style,
      children: token.content
    }, `${token.offset}-${index}`);
  };
  const renderLine = (lineTokens, index) => /*#__PURE__*/_jsx(View, {
    style: {
      flexDirection: 'row',
      flexWrap: 'wrap'
    },
    children: lineTokens.map((token, tokenIndex) => renderToken(token, tokenIndex))
  }, index);
  if (loading) {
    return /*#__PURE__*/_jsx(View, {
      style: [stylesheet.root, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/_jsx(ActivityIndicator, {})
    });
  }
  if (error) {
    return /*#__PURE__*/_jsx(View, {
      style: [stylesheet.root, {
        padding: 10
      }, containerStyle],
      children: /*#__PURE__*/_jsxs(Text, {
        style: {
          color: '#ff6b6b'
        },
        children: ["Error:", error]
      })
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    ...scrollViewProps,
    horizontal: true,
    style: [stylesheet.root, scrollViewProps?.style],
    contentContainerStyle: [containerStyle],
    children: /*#__PURE__*/_jsx(View, {
      onStartShouldSetResponder: () => true,
      children: tokens.map((lineTokens, index) => renderLine(lineTokens, index))
    })
  });
};
export default SyntaxHighlighter;
//# sourceMappingURL=SyntaxHighlighter.js.map